@@ -726,10 +726,11 @@ sub _evaluate_condition {
     # support for the match operator (with optional 'i' flag)
     if ($cond =~ /^\s*\.(.+?)\s+match\s+"(.*?)"(i?)\s*$/) {
         my ($path, $pattern, $ignore_case) = ($1, $2, $3);
-        my $re = eval {
-            $ignore_case eq 'i' ? qr/$pattern/i : qr/$pattern/
-        };
-        return 0 unless $re;
+        my ($re, $error) = _build_regex($pattern, $ignore_case);
+        if ($error) {
+            $error =~ s/[\r\n]+$//;
+            die "match(): invalid regular expression - $error";
+        }
 
         my @vals = _traverse($item, $path);
         for my $val (@vals) {
@@ -738,6 +739,24 @@ sub _evaluate_condition {
         }
         return 0;
     }
+
+    # support for the =~ operator: select(. =~ "pattern")
+    if ($cond =~ /^\s*\.(.+?)\s*=~\s*"(.*?)"(i?)\s*$/) {
+        my ($path, $pattern, $ignore_case) = ($1, $2, $3);
+        my ($re, $error) = _build_regex($pattern, $ignore_case);
+        if ($error) {
+            $error =~ s/[\r\n]+$//;
+            die "=~: invalid regular expression - $error";
+        }
+
+        my @vals = _traverse($item, $path);
+        for my $val (@vals) {
+            next if ref $val;
+            return 1 if $val =~ $re;
+        }
+
+        return 0;
+    }
  
     # pattern for a single condition
     if ($cond =~ /^\s*\.(.+?)\s*(==|!=|>=|<=|>|<)\s*(.+?)\s*$/) {
@@ -1020,6 +1039,18 @@ sub _apply_test {
     return _test_against_regex($value, $regex);
 }
 
+sub _apply_match {
+    my ($value, $pattern, $flags) = @_;
+
+    my ($regex, $error) = _build_regex($pattern, $flags);
+    if ($error) {
+        $error =~ s/[\r\n]+$//;
+        die "match(): invalid regular expression - $error";
+    }
+
+    return _test_against_regex($value, $regex);
+}
+
 sub _test_against_regex {
     my ($value, $regex) = @_;
 
